<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Pushpa
 * @since  Pushpa 1.0.0
 * @return array An array of default values
 */

function pushpa_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$pushpa_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#d87b4d',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			      => 'wide',
		'sidebar_position'         		      => 'right-sidebar',
		'post_sidebar_position' 		      => 'right-sidebar',
		'page_sidebar_position' 		      => 'right-sidebar',
		'menu_sticky'					      => (bool) false,
		'search_icon_in_primary_menu_enable'  => (bool) true,
		'search_from_enable'                  => (bool) true,
		'header_advertisement_section_enable' => (bool) true,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'pushpa' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'customizer_sortable' 			    	=> 'hero_banner,featured_posts,cta,popular_posts,most_recent_posts',
		'frontpage_sortable' 			    	=> 'hero_banner,featured_posts,cta,popular_posts,most_recent_posts_wrapper',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'pushpa' ),
		'hide_archive_post_image'		    => false,		
		'hide_archive_title'			    => false,
		'hide_category'			   			=> (bool) false,
		'hide_archive_date'			   		=> (bool) false,
		'hide_archive_content'			   	=> (bool) false,


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		// top bar
		'topbar_section_enable'			=> (bool) false,
		'social_menu_enable'			=> (bool) true,

		// hero_content
		'hero_content_section_enable'	      => (bool) false,
		'hero_content_autoplay_enable'		  => (bool) false,
		'hero_content_content_type'		      => 'post',
		'hero_content_count'				  => 3,
		'hero_content_excerpt_length'		  => 25,
		'hero_content_btn_txt'                => esc_html__('Continue more','pushpa'),

		// hero_banner section
		'hero_banner_section_enable'		=> false,
		'hero_banner_btn'			        => esc_html__( 'Read More', 'pushpa' ),


		// featured_posts section
		'featured_posts_section_enable'		    => false,
		'featured_posts_title'				    => esc_html__( 'Featured Posts', 'pushpa' ),

				//call_to_action
		'cta_section_enable' 		=> false,
		'cta_read_more'				=>	esc_html__('Call To Action', 'pushpa'),

		// popular_posts section
		'popular_posts_section_enable'		    => false,
		'popular_posts_title'				    => esc_html__( 'Popular Posts', 'pushpa' ),


		// most_recent_posts section
		'most_recent_posts_title'			    => esc_html__('Travel News', 'pushpa'),
		'most_recent_posts_section_enable'		=> false,
		'most_recent_posts_btn'			        => esc_html__( 'Read More', 'pushpa' ),



	);

	$output = apply_filters( 'pushpa_default_theme_options', $pushpa_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}